/* Convert a date-time specification in a format for strftime
	to the number of seconds since January 1, 1970.

	Written 20 February 2023, by Ruud Harmsen. See also
	https://rudhar.com/sfreview/weekly.htm
 */

#define _XOPEN_SOURCE 700
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <time.h>

void Usage (char *prog)
{
   fprintf(stderr, "Usage: %s date-time-string format-string\n", prog);
}

int main (int argc, char **argv)
{
   struct tm tm;
   time_t secs;
   char *consumed_until;

   if (argc != 3)
   {
      fprintf(stderr, "%s: Wrong number of arguments\n", argv[0]);
      Usage(argv[0]);
      exit(1);
   }
   memset(&tm, '\0', sizeof tm);
   tm.tm_isdst = -1; /* Unknown if daylight saving time in effect */
   consumed_until = strptime(argv[1], argv[2], &tm);
   if (!consumed_until)
   {
      fprintf(stderr, "%s: Conversion error in strptime, date=\"%s\", format=\"%s\"\n",
         argv[0], argv[1], argv[2]);
      Usage(argv[0]);
      exit(2);
   }
   if ((secs = mktime(&tm)) == -1)
   {
      fprintf(stderr, "%s: Conversion error in mktime\n", argv[0]);
      fprintf(stderr, "%s: CCYY-MM-DD hh:mm:ss=%04d-%02d-%02d %02d:%02d:%02d\n",
         argv[0],
         tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday,
         tm.tm_hour, tm.tm_min, tm.tm_sec);
      Usage(argv[0]);
      exit(2);
   }
   fprintf(stdout, "%lld\n", (long long)secs);

   return 0;
}
